#!/bin/bash

pollsec=120
ngraphs=2501

runName=ath.pw.genes
outbase=~/ohler_scratch_disk/RandomGraphDraws/cluster_FANMOD_template_tair10
datafiledir=~/ohler_scratch_disk/edge_groups_fanmod
drawSeedingSeeds=1
seedingSeedsFile=$runName.seedingSeeds.txt
baseNamesFile=$runName.baseNames.txt

bases=( ath_apcg.ath_xie_tss_nonxie_prec.-3000_0.FN.0.8.mismatch_5.dg_70.stringent.genes.edges ath_apcg.ath_xie_tss_nonxie_prec.-3000_0.FN.0.6.mismatch_5.dg_70.stringent.genes.edges ath_apcg.ath_xie_tss_nonxie_prec.-3000_0.FN.0.4.mismatch_5.dg_70.stringent.genes.edges ath_apcg.ath_xie_tss_nonxie_prec.-3000_0.FN.0.2.mismatch_5.dg_70.stringent.genes.edges )

useExistingSeedListsArray=0
useExistingSeedListsAll=0
useExistingSeedLists=( 1 1 1 0 0 0 0 0)

element_count=${#bases[@]}

if [ "$drawSeedingSeeds" -eq "1" ]
    then
    ./drawSeedingSeeds.sh $element_count $seedingSeedsFile
    index=0
    seedIndex=1
    if [ -f $baseNamesFile ]
	then
	rm $baseNamesFile
    fi
    while [ "$index" -lt "$element_count" ]
      do
      base=${bases[$index]}
      echo $base >> $baseNamesFile
      startingSeed=`./getInputSeed.pl $seedingSeedsFile $seedIndex`
      startingSeedFile=$base.startSEED.txt
      echo $startingSeed > $startingSeedFile
      let "index = $index + 1"
      let "seedIndex = $seedIndex + 1"
    done
    
else
    index=0
    seedIndex=1
    while [ "$index" -lt "$element_count" ]
      do
      base=${bases[$index]}
      startingSeed=`./getInputSeed.pl $seedingSeedsFile $seedIndex`
      startingSeedFile=$base.startSEED.txt
      echo $startingSeed > $startingSeedFile
      let "index = $index + 1"
      let "seedIndex = $seedIndex + 1"
    done    
fi

jobname="FS"
batchjobfile=batchjob.$jobname.q
callfile=call.$jobname.sh

index=0
while [ "$index" -lt "$element_count" ]
  do
  base=${bases[$index]}
  useExistingSeedList=${useExistingSeedLists[$index]}
  
  # poll until all jobs matching jobname have finished
  njobs=`qstat |grep mm176 | grep $jobname | wc -l`
  while [ $njobs -gt 0 ]
    do
    sleep $pollsec
    njobs=`qstat |grep mm176 | grep $jobname | wc -l`
  done
  
  # prepare for job submission
  echo "Starting $base"
  errorfile=$base.ERRORS.log
  seedFile=$base.SEEDS.txt
  
  if [ "$useExistingSeedListsArray" -eq "1" ]
      then

      if [ "$useExistingSeedList" -eq "0" ]
	  then
	  ./drawSeedLists.sh $base $ngraphs
      fi

      else

      if [ "$useExistingSeedListsAll" -eq "0" ]
	  then
	  ./drawSeedLists.sh $base $ngraphs
      fi

  fi

  ./write_batchjob_file.pl $ngraphs $jobname $callfile $errorfile $batchjobfile
  ./write_call_file.pl $base $outbase $datafiledir $seedFile $callfile
  chmod +x $callfile
  
  # submit job
  qsub $batchjobfile
  
  # poll until all jobs matching jobname have finished
  njobs=`qstat |grep mm176 | grep $jobname | wc -l`
  while [ $njobs -gt 0 ]
    do
    sleep $pollsec
    njobs=`qstat |grep mm176 | grep $jobname | wc -l`
  done
  
  # clean up
  outdir=$outbase/$base
  mv $base.* $outdir
  cp batchjob.$jobname.q $outdir
  cp $callfile $outdir

  let "index = $index + 1"
done
